lyricstools.AddLyrics
=====================

.. inheritance-diagram:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics
   :private-bases:

.. autoclass:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.contents_duration

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.duration_in_seconds

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.format

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.leaves

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.marks

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.music

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.override

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.parent

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.preprolated_duration

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.prolated_duration

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.prolation

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.set

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.spanners

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.is_parallel

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

Methods
-------

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.append

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.extend

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.index

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.insert

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.pop

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.remove

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

Special Methods
---------------

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.__add__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.__contains__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.__delitem__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.__getitem__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.__iadd__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.__imul__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.__len__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.__mul__

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.__radd__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.__repr__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.__rmul__

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.__setitem__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.AddLyrics.AddLyrics.AddLyrics.__str__

   .. note:: Inherited from `__builtin__.object`
